@@ -155,7 +155,7 @@ sub _make_header {
 sub _relink_html {
 	# $this->{save}の内容でhtmlを書換える。
 	# 書換え内容:
-	#   * form.action : 空ならREQUEST_URIにする。相対リンクならhiddenで$saveの内容を追加する。
+	#   * form.action : 空ならSCRIPT_NAMEにする。相対リンクならhiddenで$saveの内容を追加する。
 	my $this = shift;
 	my $opts = { @_ };
 	my $html = $opts->{html}; # 書換えるHTML
@@ -168,27 +168,20 @@ sub _relink_html {
 	# _relink用のキャッシュ(配列)
 	my $relink_cache = [];
 
-	my $is_xhtml = $this->{option}{type} eq 'xhtml' || 0;
-	my @intr = qw(form a);
-	$is_xhtml and push(@intr, qw(input br option));
 	my $filter = $TL->newHtmlFilter(
-		interest => \@intr,
+		interest => [qw[form input a]],
 	);
 
 	$filter->set($html);
 
 	while(my ($context, $elem) = $filter->next) {
-		my $elem_name_lc = lc($elem->name);
-		if($elem_name_lc eq 'form') {
+		if(lc($elem->name) eq 'form') {
 			my $link_unescaped = do {
 				my $action = $elem->attr('action');
 				if (!defined($action) || !length($action)) {
 					# actionが空。
-					my $uri = $ENV{REQUEST_URI} || '';
-                    
-                    # ファイル名以外を消す
-                    $uri =~ s/\?.*$//;
-					$uri =~ s|.*/([^/]+)$|$1|; 
+					my $uri = $ENV{SCRIPT_NAME} || '';
+					$uri =~ s|.*/([^/]+)$|$1|; # ファイル名以外を消す
 
 					#$TL->log(
 					#	__PACKAGE__,
@@ -209,10 +202,6 @@ sub _relink_html {
 
 			# このリンクが内部リンクなら$saveの内容を追加
 			if(!$elem->attr('EXT')) {
-				if( $is_xhtml )
-				{
-					$context->add($context->newElement('div'));
-				}
 				foreach my $key ($this->{save}->getKeys) {
 					foreach my $value ($this->{save}->getValues($key)) {
 						my $e = $context->newElement('input');
@@ -220,7 +209,7 @@ sub _relink_html {
 						$e->attr(name  => $TL->escapeTag($key));
 						$e->attr(value => $TL->escapeTag($value));
 
-						if( $is_xhtml ) {
+						if($this->{option}{type} eq 'xhtml') {
 							$e->end('/');
 						}
 
@@ -234,14 +223,10 @@ sub _relink_html {
 						$context->add($e);
 					}
 				}
-				if( $is_xhtml )
-				{
-					$context->add($context->newElement('/div'));
-				}
 			} else {
 				$elem->attr(EXT => undef);
 			}
-		} elsif($elem_name_lc eq 'a' && $elem->attr('href')) {
+		} elsif(lc($elem->name) eq 'a' && $elem->attr('href')) {
 			# hrefがあるなら、リンクを書換える。
 
 			my $newurl = $TL->escapeTag(
@@ -259,24 +244,6 @@ sub _relink_html {
 			}
 
 			$elem->attr(href => $newurl);
-		} elsif($elem_name_lc =~ /^(input|br)$/ )
-		{
-			# ここに来るのは $is_xhtml の時だけ.
-			my $end = $elem->end || '';
-			if( $end =~ s/checked// && !$elem->attr('checked') )
-			{
-				$elem->attr('checked' => 'checked');
-			}
-			$elem->end('/');
-		} elsif($elem_name_lc eq 'option' )
-		{
-			# ここに来るのは $is_xhtml の時だけ.
-			my $end = $elem->end || '';
-			if( $end =~ s/selected// && !$elem->attr('selected') )
-			{
-				$elem->attr('selected' => 'selected');
-			}
-			$elem->end($end =~ /\S/ ? $end : '');
 		}
 	}
 
