@@ -2,8 +2,7 @@
 # Tripletail::Form - フォーム情報
 # -----------------------------------------------------------------------------
 package Tripletail::Form;
-use strict;
-our $TL;
+
 
 1;
 
@@ -51,11 +50,6 @@ sub const {
 	$this;
 }
 
-sub isConst {
-	my $this = shift;
-	exists($this->{const});
-}
-
 sub clone {
 	# deep copyはせずに、キー単位でのcopy-on-writeを行う。
 	my $this = shift;
@@ -92,10 +86,9 @@ sub addForm {
 		);
 	}
 
-	my @addkeys = keys %{$form->{form}};
-	@{$this->{form}}{@addkeys} = values %{$form->{form}};
-	@{$this->{form_shared}}{@addkeys} = (1) x @addkeys;
-	@{$form->{form_shared}}{@addkeys} = (1) x keys %{$form->{form}};
+	@{$this->{form}}{keys %{$form->{form}}} = values %{$form->{form}};
+	@{$this->{form_shared}}{keys %{$form->{form}}} = (1) x keys %{$form->{form}};
+	@{$f->{form_shared}}{keys %{$form->{form}}} = (1) x keys %{$form->{form}};
 
 	@{$this->{filename}}{keys %{$form->{filename}}} = values %{$form->{filename}};
 	@{$this->{filehandle}}{keys %{$form->{filehandle}}} = values %{$form->{filehandle}};
@@ -253,40 +246,15 @@ sub set {
 		);
 	}
 
-	foreach my $key (keys %$data)
-	{
-		my $val = $data->{$key};
-		if( !defined($val) )
-		{
-			delete $this->{form}{$key};
-			delete $this->{form_shared}{$key};
-			next;
-		}
-		
-		if( !ref($val) )
-		{
-			$val = [$val];
-		}
-		if( ref($val) ne 'ARRAY' )
-		{
-			my $ref = ref($val);
+	foreach my $key (keys %$data) {
+		delete $this->{form}{$key};
+		if(ref($data->{$key}) eq 'ARRAY') {
+			$this->{form}{$key} = $data->{$key};
+		} elsif(!ref($data->{$key})) {
+			$this->{form}{$key}[0] = $data->{$key};
+		} else {
 			die "Tripletail::Form#set, ARG[]: Data include Wrong-Ref. [$key/$ref]\n";
 		}
-		
-		if( !@$val )
-		{
-			# empty list.
-			delete $this->{form}{$key};
-			delete $this->{form_shared}{$key};
-			next;
-		}
-		
-		if( my ($ref) = grep{$_} map{ref($_)} @$val )
-		{
-			die "Tripletail::Form#set, ARG[]: Data include Wrong-Ref. [$key/$ref]\n";
-		}
-		$this->{form}{$key} = [@$val]; # sharrow copy.
-		delete $this->{form_shared}{$key};
 	}
 
 	$this;
@@ -447,38 +415,6 @@ sub getFile {
 	$this->{filehandle}{$key};
 }
 
-sub existsFile {
-	my $this = shift;
-	my $key = shift;
-
-	if(ref($key)) {
-		die "Tripletail::Form#existsFile, ARG[1]: is Ref.\n";
-	}
-
-	if( defined($this->{filehandle}{$key}) )
-	{
-		return 1;
-	}
-
-	undef;
-}
-
-sub isUploaded {
-	my $this = shift;
-	my $key = shift;
-
-	if(ref($key)) {
-		die "Tripletail::Form#isUploaded, ARG[1]: is Ref.\n";
-	}
-
-	if( defined($this->{filename}{$key}) && $this->{filename}{$key} ne '' )
-	{
-		return 1;
-	}
-
-	undef;
-}
-
 sub setFile {
 	my $this = shift;
 	my $key = shift;
@@ -662,7 +598,7 @@ sub toLink {
 	}
 
 	if(!defined($base)) {
-		my $uri = $ENV{'REQUEST_URI'}||'';
+		my $uri = $ENV{'SCRIPT_NAME'}||'';
 		$uri =~ s/\?.*$//;
 		if($uri =~ m,/([^/]+)$,) {
 			$base = $1;
@@ -711,7 +647,7 @@ sub toExtLink {
 	}
 
 	if(!defined($base)) {
-		my $uri = $ENV{'REQUEST_URI'}||'';
+		my $uri = $ENV{'SCRIPT_NAME'}||'';
 		$uri =~ s/\?.*$//;
 		if($uri =~ m,/([^/]+)$,) {
 			$base = $1;
@@ -939,12 +875,6 @@ Tripletail::Form オブジェクトを作成。
 
 このメソッドを呼び出すと、以後フォームデータの変更は不可能となる。
 
-=item isConst
-
-  $form->isConst
-
-フォームオブジェクトに対して const メソッドが呼ばれたかどうかを返す。
-
 =item clone
 
   $NewForm_obj = $form->clone
@@ -1025,7 +955,6 @@ $keyが存在しなくてもエラーとはならない。
   $flag = $form->exists($key)
 
 キーが存在すれば1を、そうでなければundefを返す。
-ファイルの確認には使えない(常に偽となる)。
 
 =item remove
 
@@ -1040,21 +969,6 @@ $keyが存在しなくてもエラーとはならない。
 
 指定されたキーを削除する。キーが存在しない場合は何もしない。
 
-=item existsFile
-
-  $flag = $form->existsFile($key)
-
-アップロードキーが存在すれば1を、そうでなければundefを返す。
-ファイルが実際にアップロードされたかどうかに関わらず, キーの存在だけを
-判断します. 
-
-=item isUploaded
-
-  $flag = $form->isUploaded($key)
-
-キーに対応するファイルがアップロードされていれば1を、
-そうでなければundefを返す。
-
 =item getFile
 
   $iohandle = $form->getFile($key);
